@@ -39,11 +39,17 @@ spoiler
 stickied
 verified
 was_comment
+
+isAuto
+isHighlighted
+isInternal
+isRepliable
 /;
 
 use fields qw/session name id/;
 
 sub new {
+	# $reddit is a Reddit::Client object
     my ($class, $reddit, $source_data) = @_;
     my $self = fields::new($class);
     $self->{session} = $reddit; # could this be called something more sensible
